/******************************************************************************
 * HistogrammingElectron.hpp                                                  *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingElectron()              -- Parameterized Constructor       *
 *    ~HistogrammingElectron()             -- Destructor                      *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingElectron"    *
 *                                                                            *
 * Private Data Members of this class                                         *
 *  - lots of histograms of electron properties                               *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *****************************************************************************/

#ifndef HistogrammingElectron_h
#define HistogrammingElectron_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"



class HistogrammingElectron : public HistoCut 
{

public:

  // Parameterized Constructor
  HistogrammingElectron(EventContainer *obj);
  
  // Destructor
  ~HistogrammingElectron();

  // Get the name describing the cut
  inline std::string GetCutName() { return "HistogrammingElectron"; };

  // Book Histograms
  void BookHistogram();

  // Fill Histograms
  Bool_t Apply();
  
private:
  // Histograms declarations 
  myTH1F* _hNObj;     // Histogram of number of electrons
  myTH1F* _hPtObj1;   // Electron 1 PT
  myTH1F* _hPtObj2;   // Electron 2 PT
  myTH1F* _hEtaObj1;  // Electron 1 Eta
  myTH1F* _hEtaObj2;  // Electron 2 Eta
  myTH1F* _hPhiObj1;  // Electron 1 Phi
  myTH1F* _hPhiObj2;  // Electron 2 Phi

  myTH1F *_hPt;       // Pt of all electrons
  myTH1F *_hEta;      // Eta of all electrons
  myTH1F *_hPhi;      // Phi of all electrons
  myTH1F *_hCharge;   // Charge of all electrons 
  myTH1F *_hEoverP;   // E over P of all electrons 



};


#endif







