/******************************************************************************
 * HistogrammingJet.hpp                                                       *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingJet()              -- Parameterized Constructor            *
 *    ~HistogrammingJet()             -- Destructor                           *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingJet"         *
 *                                                                            *
 * Private Data Members of this class                                         *
 *   - lots of histograms of jet properties                                   *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *****************************************************************************/

#ifndef HistogrammingJet_h
#define HistogrammingJet_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"


class HistogrammingJet : public HistoCut 
{

public:

  // Parameterized Constructor
  HistogrammingJet(EventContainer *obj);
  
  // Destructor
  ~HistogrammingJet();

  // Get the name describing the cut
  inline std::string GetCutName() { return "HistogrammingJet"; };

  // Book Histograms
  void BookHistogram();

  // Fill Histograms
  Bool_t Apply();
  
private:
  // Histograms declarations 
  myTH1F* _hNObj;     // Histogram of number of jets
  myTH1F* _hPtObj1;   // Jet 1 PT
  myTH1F* _hPtObj2;   // Jet 2 PT
  myTH1F* _hEtaObj1;  // Jet 1 Eta
  myTH1F* _hEtaObj2;  // Jet 2 Eta
  myTH1F* _hPhiObj1;  // Jet 1 Phi
  myTH1F* _hPhiObj2;  // Jet 2 Phi

  myTH1F *_hPt;       // Pt of all jets
  myTH1F *_hEta;      // Eta of all jets
  myTH1F *_hPhi;      // Phi of all jets
  myTH1F *_hCharge;   // Charge of all jets 
  myTH1F *_hEtEM0;   // ET in EM layer 0 for all jets



};


#endif







