/******************************************************************************
 * HistogrammingMET.hpp                                                       *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingMET()              -- Parameterized Constructor            *
 *    ~HistogrammingMET()             -- Destructor                           *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingMET"         *
 *                                                                            *
 * Private Data Members of this class                                         *
 *  - histograms of MET                                                       *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      20 Nov 2006 - Modified by Bernard Pope                                *
 *****************************************************************************/

#ifndef HistogrammingMET_h
#define HistogrammingMET_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"


class HistogrammingMET : public HistoCut 
{

public:

  // Parameterized Constructor
  HistogrammingMET(EventContainer *obj);
  
  // Destructor
  ~HistogrammingMET();

  // Get the name describing the cut
  inline std::string GetCutName() { return "HistogrammingMET"; };

  // Book Histograms
  void BookHistogram();

  // Fill Histograms
  Bool_t Apply();
  
private:
  // Histograms declarations 
  myTH1F* _hMET;  // Histogram of MET
  myTH1F* _hSumEt;  // Histogram of SumEt

};


#endif







