/******************************************************************************
 * HistogrammingMET.cpp                                                       *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingMET()              -- Parameterized Constructor            *
 *    ~HistogrammingMET()             -- Destructor                           *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingMET"         *
 *                                                                            *
 * Private Data Members of this class                                         *
 *    myTH1F* _hMET                   -- Hist of MET                          *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      20 Nov 2006 - Modified by Bernard Pope                                *
 *****************************************************************************/

#include "single_top_analysis/HistogrammingMET.hpp"
#include<iostream>

using namespace std;

/******************************************************************************
 * HistogrammingMET::HistogrammingMET(EventContainer *obj)                     *
 *                                                                            *
 * Parameterized Constructor                                                  *
 *                                                                            *
 * Input:  Particle class                                                     *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingMET::HistogrammingMET(EventContainer *obj)
{
  SetEventContainer(obj);
} //HistogrammingMET()

/******************************************************************************
 * HistogrammingMET::~HistogrammingMET()                                  *
 *                                                                            *
 * Destructor                                                                 *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingMET::~HistogrammingMET()
{
  
} //HistogrammingMET

/******************************************************************************
 * void HistogrammingMET::BookHistogram()                                          *
 *                                                                            *
 * Book Histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
void HistogrammingMET::BookHistogram(){
  
  // Histogram of MET
  _hMET = DeclareTH1F("MET","Missing transverse energy",200,0.,200.);
  _hMET->SetXAxisTitle("MET [GeV]");
  _hMET->SetYAxisTitle("Events");

  // Histogram of SUM ET
  _hSumEt = DeclareTH1F("SumEt","Summed transverse energy",200,0.,2000.);
  _hSumEt->SetXAxisTitle("SumEt [GeV]");
  _hSumEt->SetYAxisTitle("Events");


  //cout<<"end of HistogrammingMET::BookHistogram"<<endl;

} //BookHistogram

/******************************************************************************
 * Bool_t HistogrammingMET::Apply()                                         *
 *                                                                            *
 * Fill histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: kTrue if successful                                                *
 ******************************************************************************/
Bool_t HistogrammingMET::Apply()
{
  //cout<<"Begin of HistogrammingMET::Apply()"<<endl;
  
  // Get Event Tree
  EventContainer *particlesObj = GetEventContainer();
  EventTree * evTree = particlesObj -> GetEventTree();
  
  // Fill Histograms
  _hMET -> Fill(evTree -> MissingEt/1000.);

  _hSumEt -> Fill(evTree -> SumEt/1000.);

  //cout<<"End of HistogrammingMET::Apply()"<<endl;
  return kTRUE;  
  
} //Apply












